SDIF Sound Description Interchange Format Download (IRCAM, Analyse/Synthèse)

# SDIFTM
Sound Description Interchange Format
Download

Copyright (C) 1997-2001 Analyse/Synthèse

Dominique Virolle, Diemo Schwarz, Xavier Rodet

This page's URL: http://www.ircam.fr/sdif/download

### SDIF-Matlab (directory)

### EaSDIF (directory)

The new Easy API to SDIF for C++, Perl, Python, Java, etc.

### SDIF Library:

README
AUTHORS
COPYING
INSTALL
ChangeLog
ReleaseNotes
SDIF-doc.tar.gz
Version 3.8.6 released 26.8.2004
SDIF-3.8.6-src.tar.gz Source tar
SDIF-3.8.6-1.src.rpm Source rpm
SDIF-3.8.6-1.i386.rpm Linux binary rpm, also built for i486, i586, i686, athlon
Version 3.8.0 released 2.2.2004
SDIF-3.8.0-src.tar.gz Source tar
SDIF-3.8.0-1.src.rpm Source rpm
SDIF-3.8.0-1.i386.rpm Linux binary rpm, also built for i486, i586, i686, athlon
SDIF-3.8.0-1.MacOSX.dmg Mac binary OS-X 10.3 framework with auto-installer

Version 3.7.4 released 23.05.2003
SDIF-3.7.4-src.tar.gz
SDIF-3.7.4-1.i386.rpm
SDIF-3.7.4-2-bin-MacOSX.dmg Mac OS-X framework as auto-installer, thanks to Riccardo Borghesi et Jean Bresson

Version 3.7.3 released 7.3.2003
SDIF-3.7.3-src.tar.gz
SDIF-3.7.3-1.i386.rpm
SDIF-3.7.3-1.src.rpm

Version 3.7.2 released 17.12.2002
SDIF-3.7.2-src.tar.gz
SDIF-3.7.2-1.i386.rpm

Version 3.7.1 released 30.10.2002
SDIF-3.7.1-src.tar.gz
SDIF-3.7.1-1.i386.rpm
SDIF-3.7.1-bin-Win32.zip built with MS Visual C++ 7.0 (.net) thanks to Michael Gogins (gogins at pipeline.com)

Version 3.7.0 released 20.9.2002
SDIF-3.7.0-src.tar.gz
SDIF-3.5-src.tar.gz
SDIF-3.4-src.tar.gz
SDIF-3.4.0-bin-Mac.sit
SDIF-3.4.0-bin-Mac.zip
SDIF-3.3-src.tar.gz
SDIF-3.2.2-bin-Mac.sit
SDIF-3.2.2-src.tar.gz
SDIF-3.2.alpha-WIN32.tar.gz
SDIF-3.2.1-bin-Mac.sit
SDIF-3.2.0-bin-Linux.tar.gz
SDIF-3.2.0-bin-Mac.sit
SDIF-3.2.0-bin-Mac.zip
SDIF-3.2.0-bin-sgi.tar.gz
SDIF-3.2.0-src-Mac-CwPro5.sit
SDIF-3.2.0-src-Mac-CwPro5.zip
SDIF-3.2.0-src.tar.gz

SDIF is a registered trademark, registered September 23, 1999 at INPI (Institut National de la Proprieté Industrielle), Paris, France for IRCAM - Centre Georges Pompidou, registration number 99/814815.